import AxiamoSkin 1.0
import QtQuick 2.2
import QtQuick.Controls 1.2
import Qt.labs.settings 1.0

import "../Logic/PlotterHandling.js" as PlotMan

AppScreen{
    Component.onCompleted: {
        setFeedbackType(archiveSettings.feedbackName,archiveSettings.feedbackVal);
    }

    function newPlotter(measurementId,deviceId){
           console.log('archive.qml got new plotter for measurement: ' + measurementId + ' and device: ' + deviceId);
            var staticPlotter = plotController.getStaticPlotter(measurementId,deviceId);
            showplotter(staticPlotter);
    }

    function showplotter(staticPlotter){
            staticPlotter.parent = plotRect;
            staticPlotter.width = parent.width;
            staticPlotter.updateGraphs();
            staticPlotter.visible=true;
            PlotMan.resizeAllPlotters();
            console.log('QML Plotter was shown and updated.');
    }

    function showPlotRect(){
        plotRectFrame.visible = 1;
        plotRectFrame.height = parent.height;
        plotRectFrame.width = parent.width;
    }

    function setFeedbackType(name, val){
        btnSelectFeedback.buttonText = " Feedback: " + name;
        processorController.setProcessorAttributes(val);
        archiveSettings.feedbackName = name;
        archiveSettings.feedbackVal = val;
        console.log('Setting feedback type :  ' + name + ',  ' + val);
    }

    Settings {
        id: archiveSettings
        property string feedbackName: "all"
        property string feedbackVal: ""
    }


    Row{
        id: topRow;
        spacing: 10
        BasicButton{
            id: btnAverages;
            buttonText: "Show Feedback";
            onClicked: processorController.processMeasurements(1);
        }

        BasicButton{
            buttonWidth: 300*dip;
            id: btnSelectFeedback;
            buttonText: "Select Feedback: ";
            onClicked: {
                 feedBackListOverlay.visible=true;
            }
        }


    }
    ListView {
            id: measurementsOnDeviceList

            anchors.top:    topRow.bottom
            anchors.bottom: parent.bottom
            anchors.topMargin: 10
            width: parent.width
            model: measurementsModel
            delegate: measurementListDelegate
            spacing: 5
            Component {
                id: measurementListDelegate
                MeasurementDelegate{
                    width: parent.width
                    measurementId:MeasurementID
                    appName: AppName
                    userName: UserName
                    setupName: SetupName
                    startTime: StartTime
                    onDeleteClicked: {
                        var  confirmObject = msgConfirm.createObject(mainFrame,{
                                                                      messageTitle: qsTr('Delete measurement?'),
                                                                      messageText: qsTr('This cannot be undone.')
                                                                  });

                        confirmObject.yes.connect(function(){
                                measurementsModel.removeRows(index,1);
                                confirmObject.destroy();
                             }
                            );

                        confirmObject.no.connect(
                                    function(){
                                        confirmObject.destroy();
                                    }
                        );
                    }
                    onUploadClicked: uploadController.uploadMeasurement(MeasurementID);
                    onProcessClicked: {
                        console.log('Start Processing for id: ' + MeasurementID);
                        processorController.processMeasurement(MeasurementID,1);
                    }

                    onExportClicked: {
                        console.log('Export measurement by id: ' + MeasurementID);
                        measurementController.loadMeasurementDataFromDisk(MeasurementID);
                        measurementController.exportMeasurement(MeasurementID);
                    }
                    onClicked: {
                        console.log('User clicked on measurement:' + measurementId);
                        console.log('App Name when on measurement clicked: ' + appName);

                        if (appName == 'Basic'){
                            console.log('User clicked Basic measurement!');
                            plotController.setPlotterType(1);
                        }
                        if (appName == 'SquatJump'){
                            console.log('User clicked SquadJump measurement!');
                            plotController.setPlotterType(2);
                        }
                        if (appName == 'Sprint'){
                            console.log('User clicked Sprint measurement!');
                            plotController.setPlotterType(3);
                            plotController.setSetupName(setupName);
                        }
                        measurementController.loadMeasurementDataFromDisk(MeasurementID)
                        plotController.createStaticPlotters(measurementId);
                        showPlotRect();

                    }
                  }
            }
    }
    Rectangle{
        anchors.fill: parent
        border.width: 5;
        id: plotRectFrame;
        visible: false;

        Component.onCompleted: {
        console.log('debug qml component initation');
            if(!initDone){
                plotController.staticPlotterCreated.connect(newPlotter);
                console.log('Archive Component completed, connecting signals and slots. ');
                initDone=true;
           }
          console.log('Archive Component completed, init done?' + initDone);

        }

        Column{
            id: plotRect
            anchors.fill: parent
            }
        PictureButton{
            buttonImage: iconPath + 'actions/close.png'
            anchors { right: parent.right; top:parent.top }
            buttonWidth: 24*dip;
            buttonHeight: 24*dip;
            internalMargin: 0;
            onClicked: {
                console.log('Close Plotter.');
                plotRectFrame.visible = false;

                while( plotRect.children.length > 0 ){
                    var plotter = plotRect.children[0];
                    console.log('Removing plotter object: ' + plotter);
                    plotter.parent=null;
                }
            }
        }


    }

   OverlayScreen{
        id: feedBackListOverlay
         visible: false
        ListModel{
            id: dataModel
            ListElement{ name: "all";      val: "" }
            ListElement{ name: "4-5-6-10"; val:"4-5-6-10"  }
            ListElement{ name: "2-3-4-7";  val: "2-3-4-7";}
            ListElement{ name: "2-3-4-6"; val: "2-3-4-6" }
            ListElement{ name: "2-3-4-8"; val: "2-3-4-8" }
            ListElement{ name: "4-5-6-10"; val: "4-5-6-10";}
            ListElement{ name: "2-3-4-7"; val: "2-3-4-7"}
            ListElement{ name: "2-3-4-6"; val: "2-3-4-6"}
            ListElement{ name: "2-3-4-8"; val: "2-3-4-8" }
        }
        width:  200*dip
        height: 400*dip


        ListView {

                id: feedbackList
                anchors.fill: parent
                clip:true
                model: dataModel
                delegate: feedbackListDelegate
                spacing: 5
                anchors.left: parent.left
                anchors.margins: 10
                width: parent.width
                Component {
                    id: feedbackListDelegate
                        BasicButton{
                            buttonWidth:parent.width
                            buttonText: name
                            onClicked: {
                                setFeedbackType(name,val);
                                feedBackListOverlay.visible=false;
                            }
                }
            }
    }

    }

}
