import QtQuick 2.1
import "Palette.js" as Palette


Item{

    height: actionButtonHeight

    property color normalColor: Palette.middle
    property color hoverColor:  Palette.light1
    property color pressedColor: Palette.dark1

    property bool showDelete: false
    property bool showCreate: false
    property bool showExpand: false
    property bool showUpload: false
    property bool showExport: false
    property bool showIdentify: false
    property bool showProcess: false

    signal deleteClicked;
    signal createClicked;
    signal expandClicked;
    signal uploadClicked;
    signal exportClicked;
    signal identifyClicked;
    signal processClicked;


    property int actionButtonWidth:30*dip
    property int actionButtonHeight:30*dip


    property list<QtObject> buttonModel: [
        QtObject { property string name: "delete"; property string icon: "delete.png"; property bool show: showDelete; property int code: 0},
        QtObject { property string name: "create"; property string icon: "create.png"; property bool show: showCreate; property int code: 1},
        QtObject { property string name: "expand"; property string icon: "expand.png"; property bool show: showExpand; property int code: 2},
        QtObject { property string name: "upload"; property string icon: "upload.png"; property bool show: showUpload; property int code: 3},
        QtObject { property string name: "export"; property string icon: "export.png"; property bool show: showExport; property int code: 4},
        QtObject { property string name: "identify"; property string icon: "identify.png"; property bool show: showIdentify; property int code: 5},
        QtObject { property string name: "process"; property string icon: "process.png"; property bool show: showProcess; property int code: 6}
      ]


    Row {
        anchors.right: parent.right
        anchors.verticalCenter: parent.verticalCenter
        anchors.margins: 7*dip
        spacing: 5*dip

        Repeater {
            model:      buttonModel
            delegate:   listActionButton
        }
        Component{
             id: listActionButton

             Rectangle{
                 id: listActionButtonFrame
                 state : "Normal"
                 states: [
                         State {
                             name: "Normal"
                             PropertyChanges { target: listActionButtonFrame; color: normalColor}
                         },
                         State {
                             name: "Hover"
                             PropertyChanges { target: listActionButtonFrame; color: hoverColor}
                         },
                         State {
                             name: "Pressed"
                             PropertyChanges { target: listActionButtonFrame; color: pressedColor}
                         }
                     ]

                 border.color: Palette.dark2

                 radius: 3*dip
                 color: Palette.middle
                 visible: show
                 width: actionButtonWidth
                 height: actionButtonHeight
                 anchors.margins: 5*dip
                 Image{
                    fillMode: Image.PreserveAspectFit
                    source: "images/actions/" + model.modelData.icon
                    anchors.fill: parent
                    anchors.margins: 5*dip

                 }
                 MouseArea{
                     hoverEnabled: true
                     width: actionButtonWidth
                     height: actionButtonHeight
                     onClicked: {
                         switch(model.modelData.code){
                         case 0:
                             deleteClicked();
                         break;
                         case 1:
                             createClicked();
                         break;
                         case 2:
                             expandClicked();
                         break;
                         case 3:
                             uploadClicked();
                         break;
                         case 4:
                             exportClicked();
                         break;
                         case 5:
                             identifyClicked();
                         break;
                         case 6:
                             processClicked();
                         break;

                         }
                     }

                     onPressed:  {
                         listActionButtonFrame.state="Pressed";
                     }
                     onEntered:{
                         listActionButtonFrame.state="Hover"
                     }
                     onExited:{
                         listActionButtonFrame.state="Normal";
                     }

                     onReleased:{
                       listActionButtonFrame.state="Normal";
                     }
                 }
              }

         }
    }
}
