import QtQuick 2.1
import QtQuick.Window 2.0
import "Palette.js" as Palette

Rectangle{
    readonly property real dip: Screen.pixelDensity / (96 / 25.4) // DPI norm in mm

    id: buttonFrame




    signal clicked()

    property int buttonBorderWidth: 5*dip
    property int buttonRadius: 10
    property int buttonWidth: 0*dip
    property int buttonHeight: 0*dip
    property alias buttonText: buttonText.text
    property int buttonfontSize: 12*dip
    property int internalMargin: 15

    property color normalColor: Palette.middle
    property color hoverColor:  Palette.light1
    property color pressedColor: Palette.light2
    property bool buttonHoverEnabled: true

    border.width: buttonBorderWidth
    border.color: normalColor
    radius: buttonRadius


    state : "Normal"
    states: [
            State {
                name: "Normal"
                PropertyChanges { target: buttonFrame; color: normalColor}
            },
            State {
                name: "Hover"
                PropertyChanges { target: buttonFrame; color: hoverColor}
            },
            State {
                name: "Pressed"
                PropertyChanges { target: buttonFrame; color: pressedColor}
            }
        ]

                Text {
                    id: buttonText
                    anchors.centerIn: parent
                    anchors.margins: internalMargin
                    font.pixelSize: buttonfontSize
                    color: Palette.text
                }

    MouseArea {
        id: mousearea
        hoverEnabled: true
        anchors.fill: parent
        onPressed:  {
            buttonFrame.state="Pressed";
        }
        onEntered:{
            if(buttonHoverEnabled){
                buttonFrame.state="Hover";
               }
        }
        onExited:{
            if(buttonHoverEnabled){
                buttonFrame.state="Normal";
            }
        }

        onReleased:{
          buttonFrame.state="Normal";
        }

    }
    onButtonWidthChanged: {
        applyButtonSize();
    }

    onButtonHeightChanged: {
        applyButtonSize();
    }
    function applyButtonSize(){

        if(buttonWidth <= 0){
            buttonFrame.width = buttonText.paintedWidth + internalMargin;
         }else{
            buttonFrame.width = buttonWidth
        }

        if(buttonHeight <= 0){
           buttonFrame.height = buttonText.paintedHeight + internalMargin;
        }else{
            buttonFrame.height = buttonHeight
        }
    }

    Component.onCompleted: {
            mousearea.clicked.connect(clicked);
            applyButtonSize();
        }
}
