import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Window 2.2
import QtQuick.Dialogs 1.2
import AxiamoSkin 1.0
import "../../../apps/Basic/BasicLogic.js" as BasicLogic
import "../../../apps/Basic/Navigation.js" as NavLogic

import "Palette.js" as Palette

ApplicationWindow {
    title:  helper.versionCodeHostSoftware();
    width:  appWidth
    height: appHeight
    visible:true
    property int sideMargin: 10

    function setupSuceeded(){
        console.log('QML: Setup suceeded');
        msgProgressConfig.state = "suceeded";
        BasicLogic.setupSuceeded();
    }

    function setupFailed(){
        console.log('QML: Setup failed');
        msgProgressConfig.state = "failed";
    }

    function updateProgressConfig(InfoString,ProgressNumber){
        console.log('Info from notificationHub: ' + InfoString);
        msgProgressConfig.messageTitle = qsTr('Configuration in progress');
        msgProgressConfig.messageText =  qsTr('' + Math.round(ProgressNumber * 100) + ' %');
        msgProgressConfig.progress = ProgressNumber;

        if(ProgressNumber >0 &&  ProgressNumber < 1){
            msgProgressConfig.state = "shown";
        }
    }

    MainFrame{
        id: mainFrame
        sideMargin:sideMargin
        Title{
            id: mainTitle
            showLogo: true
            onLogoClicked: versionInfo.visible=true;
        }

        Navigation{
            id: mainNav
             model: navigationItems;
            anchors.top: mainTitle.bottom
            width: parent.width
            onItemClicked: {
                NavLogic.navigationClicked(index);
            }
            Component.onCompleted: {
                notificationHub.progressConfig.connect(updateProgressConfig);
                setupController.setupDone.connect(setupSuceeded);
                setupController.setupFailed.connect(setupFailed);
            }
        }



            ScreenList{
                id:appScreens

                anchors.top: mainNav.bottom
                anchors.bottom:  status.top
                anchors.left: mainFrame.left
                anchors.right: mainFrame.right

                model: navigationItems;
               cacheBuffer: 10;
                onCurrentIndexChanged: {
                     NavLogic.highlightActive(currentIndex);
                }

            }




        Status{
            id: status
            statusNumDevConnected: devManager.numDevConnected
            statusNumDevTotal: devManager.numDevTotal
            statusNumTasks: stateController.numMessages
            bluetoothState: interfaceManager.btScanStatus;
        }


        NumberAnimation { id: screenListAnim; running:false; target: appScreens; property: "contentX"; duration: 200 }


    Component{
        id: msgConfirm
        MessageBox{
            showMessage: true
            showInput: false
            showYes:true;
            showNo:true;
            showOk: false;
            showCancel: false;
            messageTitle: qsTr("Sure");
            messageText:  qsTr("Sure to?");
         }
   }

    VersionInfoBox{
        id: versionInfo
        visible: false;
        showOk: true;
        messageTitle: qsTr("Version Info");
        versionCode: helper.versionCodeHostSoftware();
        revision:  helper.revisionHostSoftware();
        buildDate: helper.buildDateHostSoftware();
        onOk: versionInfo.visible=false;
     }
        ProgressBox{
            id: msgProgressConfig
            messageTitle: qsTr("Progress");
            messageText:  qsTr("Ongoing");
            onCancel: BasicLogic.abortConfiguration();
         }

        OverlayScreen{
            id: sensorList
            visible: false
            ListView {
                    id: deviceList
                    anchors.fill: parent
                    clip:true
                    model: devModel
                    delegate: deviceistDelegate
                    spacing: 5
                    anchors.left: parent.left
                    anchors.margins: 10

                    Component {
                        id: deviceistDelegate
                            SensorDelegate{
                                width: parent.width
                                serial: Name
                                firmware:Firmware
                                usbPort: UsbPort
                                btAddress: BtAddress
                                btConnected: BtConnected
                                usbConnected: UsbConnected
                                topState: TopState
                                onlineState: Online
                                onShowMeasurementsForSensor: uploadController.uploadMatFromDevice(Name)
                                onDeleteClicked: {
                                    console.log('Delete clicked: ' + index);
                                    devModel.removeRows(index,1);
                                   }
                            }
                    }
                }
        }

   }

}
