import QtQuick 2.1
import QtQuick.Window 2.0
import "Palette.js" as Palette

Item{
    id: dialogRoot
    readonly property real dip: Screen.pixelDensity / (96 / 25.4) // DPI norm in mm

    property string messageTitle: "Message title"
    property string messageText: "Message text"
    property alias  inputText: inputLine.text
    property color  bgColor:    Palette.light2
    property color  borderColor:    Palette.dark1

    //property alias width: messageFrame.width
    property alias dialogWidth: messageFrame.width
    property alias dialogHeight: messageFrame.height


    property bool showOk    : true;
    property bool showYes   : false;
    property bool showNo   : false;
    property bool showCancel: true;
    property bool showInput: true;
    property bool showMessage: true;

    signal ok
    signal yes
    signal no
    signal cancel

    anchors.fill: parent

    MouseArea{
        anchors.fill: parent
        hoverEnabled: true

    }
    Rectangle{
        id: hideBackGroundElements
        color: "white"
        opacity: .3
        anchors.fill: parent;
    }
    Rectangle{

        id: messageFrame

        anchors.horizontalCenter: parent.horizontalCenter;
        anchors.top: parent.top;
        width: 200*dip;
        height: 175*dip;
        border.width: 2*dip;
        border.color:borderColor
        color: bgColor
        radius: 10
        Title{
            id: title
            anchors.topMargin:2
            titleText: messageTitle
            titleHeight: 40*dip
        }
        Column{
            id: messageAndInput
            anchors.top: title.bottom
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.margins: 10
            anchors.topMargin: 15
            spacing: 5

            Text{
                visible: showMessage;
                id:message
                text:messageText
                font.pixelSize: 14
            }
            Rectangle{
                visible: showInput
                border.color: Palette.dark2
                border.width: 1
                radius: 2
                height: 35*dip;
                width: parent.width

                TextInput{
                    anchors.centerIn: parent
                    anchors.margins: 2
                    id: inputLine
                    focus: false
                    width: parent.width-4
                    cursorVisible: true
                    height:parent.height;
                }
            }
        }

        Row{
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: messageAndInput.bottom
            anchors.margins: 5
            spacing: 5
            BasicButton{
                visible: showOk
                buttonText: qsTr("OK")
                onClicked: ok();
            }

            BasicButton{
                visible: showYes
                buttonText: qsTr("Yes")
                onClicked: yes();
            }
            BasicButton{
                visible: showNo
                buttonText: qsTr("No")
                onClicked: no();
            }
            BasicButton{
                visible: showCancel
                buttonText: qsTr("Cancel")
                onClicked: cancel();
            }

        }
    }
    Component.onCompleted:{
        if(showInput){
            inputLine.selectAll();
        }
    }
}
