import QtQuick 2.1
import QtQuick.Window 2.0
import "Palette.js" as Palette

Rectangle{
    readonly property real dip: Screen.pixelDensity / (96 / 25.4) // DPI norm in mm
    id: buttonFrame
    border.width: 5*dip
    border.color: normalColor

    //anchors.horizontalCenter: parent.horizontalCenter

    signal clicked()

    property int buttonWidth: 0*dip
    property int buttonHeight: 40*dip
    property int buttonRadius: 10*dip
    property alias buttonText: buttonText.text
    property int buttonfontSize: 14*dip
    property alias buttonImage: buttonImage.source
    property int internalMargin: 6*dip

    property color normalColor: Palette.middle
    property color hoverColor:  Palette.light1
    property color pressedColor: Palette.dark1

    width: buttonWidth > 0 ? buttonWidth : parent.width-60
    height: buttonHeight
    radius: buttonRadius

    state : "Normal"
    states: [
            State {
                name: "Normal"
                PropertyChanges { target: buttonFrame; color: normalColor}
            },
            State {
                name: "Hover"
                PropertyChanges { target: buttonFrame; color: hoverColor}
            },
            State {
                name: "Pressed"
                PropertyChanges { target: buttonFrame; color: pressedColor}
            }
        ]

                Image{
                   id: buttonImage;
                   fillMode: Image.PreserveAspectFit
                   anchors.verticalCenter:  parent.verticalCenter
                   anchors.left: buttonFrame.left
                   anchors.margins: internalMargin
                   height: buttonHeight-internalMargin
                }
                Text {
                    id: buttonText
                    anchors.verticalCenter:  parent.verticalCenter
                    anchors.left: buttonImage.right
                    anchors.margins: internalMargin
                    font.pixelSize: buttonfontSize
                    color: Palette.text
                }

    MouseArea {
        id: mousearea
        hoverEnabled: true
        anchors.fill: parent
        onPressed:  {
            buttonFrame.state="Pressed";
        }
        onEntered:{
            buttonFrame.state="Hover"
        }
        onExited:{
            buttonFrame.state="Normal";
        }

        onReleased:{
          buttonFrame.state="Normal";
        }

    }

    Component.onCompleted: {
            mousearea.clicked.connect(clicked)
        }

}
