import QtQuick 2.1
import QtQuick.Window 2.0
import QtQuick.Controls 1.3

import "Palette.js" as Palette

Item{
    id: dialogRoot

        readonly property real dip: Screen.pixelDensity / (96 / 25.4) // DPI norm in mm

        property string messageTitle: "Message title"
        property string messageText: "Message text"
        property alias  progress: progressIndicator.value
        property color  bgColor:    Palette.light2
        property color  borderColor:    Palette.dark1

        property alias dialogWidth: messageFrame.width
        property alias dialogHeight: messageFrame.height

        property bool showCancel: true;
        property bool showMessage: true;
        property bool showTitle: true;
        property bool showProgress: true;
        property bool showSuccess:false;
        property bool showFail:false;

        property alias blockInput: hideBackGroundElements.visible;

        property int collapsedHeight : 85*dip;
        property int expandedHeight : 175*dip;
        signal cancel

        anchors.fill: parent
        state: "hidden";

        Timer {
                id: hideTimer
                 interval: 1000; running: false; repeat: false
                 onTriggered: state="hidden"
             }

        Rectangle{
            id: hideBackGroundElements
            color: "white"
            opacity: .3
            anchors.fill: parent;
            MouseArea{
                anchors.fill: parent
                hoverEnabled: true
            }
        }
        Rectangle{

            id: messageFrame

            anchors.horizontalCenter: parent.horizontalCenter;
            anchors.top: parent.top;
            width: 200*dip;
            height: expandedHeight;
            border.width: 2*dip;
            border.color:borderColor
            color: bgColor
            radius: 10*dip
            Title{
                id: title
                visible: showTitle;
                anchors.topMargin:2
                titleText: messageTitle
                titleHeight: 40*dip
            }
            Column{
                id: messageAndProgress
                anchors.top: title.bottom
                anchors.bottom: parent.bottom
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.margins: 10*dip
                anchors.topMargin: 15*dip
                spacing: 5*dip

                Row{
                    anchors.horizontalCenter: parent.horizontalCenter;
                    Image{
                       visible: showSuccess;
                       fillMode: Image.PreserveAspectFit
                       source: "images/indicators/success.png"
                       anchors.margins: 5*dip
                    }
                    Image{
                       visible: showFail;
                       fillMode: Image.PreserveAspectFit
                       source: "images/indicators/fail.png"
                       anchors.margins: 5*dip
                    }

                    Text{
                        id:message
                        visible: showMessage;
                        text:messageText
                        font.pixelSize: 14*dip;

                    }
                }
                ProgressBar {
                      visible: showProgress;
                      id: progressIndicator;
                      anchors.left: parent.left;
                      anchors.right: parent.right;
                      value: 0.5
                 }

            }

            Row{
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.bottom: messageAndProgress.bottom
                anchors.margins: 5*dip
                spacing: 5*dip

                BasicButton{
                    visible: showCancel
                    buttonText: qsTr("Cancel")
                    onClicked: cancel();
                }

            }
        }

    states:[
       State {
        name:"hidden"
        PropertyChanges {target:msgProgressConfig;visible:false;}
       },
       State {
            name:"shown"
            PropertyChanges {target:msgProgressConfig;visible:true;height: expandedHeight;}
       },
        State {
             name:"suceeded"
             PropertyChanges {  target:msgProgressConfig;
                                visible:true;
                                blockInput:false;
                                showTitle:true;
                                showMessage:true;
                                showCancel:false;
                                showProgress:false;
                                showSuccess:true;
                                progress : 1;
                                messageText: qsTr('Suceeded');


             }

             PropertyChanges{
                 target: messageFrame
                 height: collapsedHeight;
             }
             PropertyChanges{
                 target: hideTimer
                 running: true;
            }
         },
        State{
                     name:"failed"
                     PropertyChanges {  target:msgProgressConfig;
                                        visible:true;
                                        blockInput:false;
                                        showTitle:true;
                                        showMessage:true;
                                        showCancel:false;
                                        showProgress:false;
                                        showSuccess:false;
                                        showFail:true;
                                        progress : 0;
                                        messageText: qsTr('Failed');

                     }

                     PropertyChanges{
                         target: messageFrame
                         height: collapsedHeight;
                     }
                     PropertyChanges{
                         target: hideTimer
                         running: true;
                    }
                 }


     ]
}
