import QtQuick 2.1
import QtQuick.Layouts 1.1
import QtQuick.Window 2.0
import "Palette.js" as Palette

    Rectangle{
        readonly property real dip: Screen.pixelDensity / (96 / 25.4) // DPI norm in mm
        id: sensor
        property int modelIndex: 0
        property string onlineState: ''
        property string btConnected: ''
        property string usbConnected: ''
        property string serial: '0'
        property string firmware: '0'
        property string usbPort: ''
        property string btAddress: ''
        property string topState: ''
        property int labelWidth: 100*dip;
        property int colWidth: 300*dip;
        property color normalColor: Palette.middle
        property real sensorMeasurementsOpacity : 0
        property int fontSize: 12*dip

        property int expandedHeight : 300*dip;
        property int collapsedHeight : 150*dip;

        signal showMeasurementsForSensor(string deviceSerial)
        signal deleteClicked;

        color: normalColor
        state:'sensorMeasurementsHidden'


        width: 300*dip
        Title{
            id: propertiesTitle
            titleText: qsTr("Sensor        ") + serial + '              ' + onlineState;
            titleFontSize: 14*dip
            titleHeight: 60*dip
            internalMargin: 5*dip

            ActionButtons{
                anchors.right: parent.right
                anchors.verticalCenter: parent.verticalCenter
                showExpand: true;
                showIdentify: true;
                showDelete: true;
                onDeleteClicked: sensor.deleteClicked();

                onIdentifyClicked: {
                    console.log('identify clicked.' + serial);
                     uploadController.identifySensor(serial);
                  }
                onExpandClicked: {
                    showMeasurementsForSensor(serial);
                    if(sensor.state=="sensorMeasurementsVisible"){

                        sensor.state="sensorMeasurementsHidden"
                    }else{

                        sensor.state="sensorMeasurementsVisible"
                    }
                }
            }
        }

        GridLayout{
            id: propertyGrid
            columns: 3
            anchors.top: propertiesTitle.bottom
            anchors.left: parent.left
            anchors.leftMargin: 10
            Text {

                width: labelWidth
                id: serialLabelCap
                text: qsTr("Serial:")
                font.pixelSize: fontSize
           }
           Text {
               Layout.columnSpan: 2
               width: colWidth
               id: serialLabel
               text: serial
               font.pixelSize: fontSize
           }
           Text {
               width: labelWidth
               id: firmwareLabelCap
               text: qsTr("Firmware Revision:")
               font.pixelSize: fontSize
           }

           Text {
               Layout.columnSpan: 2
               width: colWidth
               id: firmwareLabel
               text: firmware
               font.pixelSize: fontSize
           }

           Text {
               width: labelWidth
               id: usbLabelCap
               text: qsTr("USB:")
               font.pixelSize: fontSize
          }
          Text {
              width: colWidth
              id: usbLabel
              text: usbPort
              font.pixelSize: fontSize
          }
          Text {
              width: colWidth
              id: usbConnLabel
              text: usbConnected
              font.pixelSize: fontSize
          }

          Text {
              width: labelWidth
              id: btLabelCap
              text: qsTr("Bluetooth:")
              font.pixelSize: fontSize
         }
         Text {
             width: colWidth
             id: btLabel
             text: BtAddress
             font.pixelSize: fontSize
         }
         Text {
             width: colWidth
             id: btConnLabel
             text: BtConnected
             font.pixelSize: fontSize
         }
         Text {
             width: labelWidth
             id: stateLabelCap
             text: qsTr("State:")
             font.pixelSize: fontSize
         }

         Text {
             Layout.columnSpan: 2
             width: colWidth
             id: stateLabel
             text: topState
             font.pixelSize: fontSize
         }

         Text {
             Layout.alignment: Qt.AlignTop
             width: labelWidth
             id: measurementsLabelCap
             text: qsTr("Measurements:")
             opacity:sensor.sensorMeasurementsOpacity
             font.pixelSize: fontSize
         }

          Rectangle{
              Layout.alignment: Qt.AlignTop
              Layout.columnSpan: 2
              width: colWidth
              height:200*dip
              opacity:sensor.sensorMeasurementsOpacity
              color: normalColor
              ListView{
                      clip: true
                      anchors.fill: parent
                      model: devModel.getMeasurementsOnDeviceModel(serial);
                      spacing: 3*dip
                      delegate: sensorMeasurement
              }
          }
        }

        Component{
            id: sensorMeasurement

                Text{
                    anchors.left: parent.left
                    width: 200*dip
                    height: 30*dip
                    font.pixelSize: fontSize
                    text: MeasurementID
            }
        }

    states:[
            State {
                 name: "sensorMeasurementsVisible"
                 PropertyChanges { target: sensor; sensorMeasurementsOpacity: 1; height:expandedHeight}
             },
            State {
             name: "sensorMeasurementsHidden"
                 PropertyChanges { target: sensor; sensorMeasurementsOpacity: 0; height:collapsedHeight}
         }
       ]
    transitions:[
        Transition{
            from:   'sensorMeasurementsHidden'
            to:     'sensorMeasurementsVisible'
            SequentialAnimation{
                NumberAnimation { duration: 100; properties: "height" }
                NumberAnimation { duration: 100; properties: "sensorMeasurementsOpacity" }
            }
        },
        Transition{
            from:   'sensorMeasurementsVisible'
            to:     'sensorMeasurementsHidden'
            SequentialAnimation{
                NumberAnimation { duration: 100; properties: "sensorMeasurementsOpacity" }
                NumberAnimation { duration: 100; properties: "height" }
            }
        }

    ]

 }

