import QtQuick 2.1
import QtQuick.Window 2.0
import "Palette.js" as Palette

Item{
    id: dialogRoot
    readonly property real dip: Screen.pixelDensity / (96 / 25.4) // DPI norm in mm

    property string messageTitle: "Message title"
    property color  bgColor:    Palette.light2
    property color  borderColor:    Palette.dark1

    //property alias width: messageFrame.width
    property alias dialogWidth: messageFrame.width
    property alias dialogHeight: messageFrame.height
    property alias versionCode: versionCode.text
    property alias revision: revision.text
    property alias buildDate: buildDate.text


    property bool showOk            : true;
    property bool showVersionCode   : true;
    property bool showGitRevision   : true;
    property bool showBuildDate     : true;

    signal ok

    anchors.fill: parent

    MouseArea{
        anchors.fill: parent
        hoverEnabled: true

    }
    Rectangle{
        id: hideBackGroundElements
        color: "white"
        opacity: .3
        anchors.fill: parent;
    }
    Rectangle{

        id: messageFrame

        anchors.horizontalCenter: parent.horizontalCenter;
        anchors.top: parent.top;
        width: 200*dip;
        height: 175*dip;
        border.width: 2*dip;
        border.color:borderColor
        color: bgColor
        radius: 10
        Title{
            id: title
            anchors.topMargin:2
            titleText: messageTitle
            titleHeight: 40*dip
        }
        Column{
            id: versionInfo
            anchors.top: title.bottom
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.margins: 10
            anchors.topMargin: 15
            spacing: 5
            Item{
                anchors.left: parent.left
                anchors.right: parent.right
                height: 14*dip;
                visible: showVersionCode
                id:versionCodeRow

                Text{
                    id:lblVersionCode
                    text:qsTr("Version code:");
                    font.pixelSize: 14
                    anchors.left: parent.left
                }
                Text{
                    id:versionCode
                    font.pixelSize: 14
                     anchors.right: parent.right
                }
            }
            Item{
                anchors.left: parent.left
                anchors.right: parent.right
                height: 14*dip;
                visible: showVersionCode
                id:revisionRow
                Text{
                    id:lblRevision
                    text:qsTr("Revision: ");
                    font.pixelSize: 14
                    anchors.left: parent.left
                }
                Text{
                    id:revision
                    font.pixelSize: 14
                     anchors.right: parent.right
                }
            }
            Item{
                anchors.left: parent.left
                anchors.right: parent.right
                height: 14*dip;
                visible: showBuildDate
                id:buildDateRow
                Text{
                    id:lblBuildDate
                    text:qsTr("Builddate: ");
                    font.pixelSize: 14
                    anchors.left: parent.left
                }
                Text{
                    id:buildDate
                    font.pixelSize: 14
                     anchors.right: parent.right
                }
            }

        }

        Row{
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: versionInfo.bottom
            anchors.margins: 5
            spacing: 5
           BasicButton{
                visible: showOk
                buttonText: qsTr("OK")
                onClicked: ok();
            }


        }
    }

}
